Page 124 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 124

Home

    Champion." In a 1988 interview Mr. Alburt had this to
    say about religion in the Soviet Union:

    in the American sense of the word religious freedom.
    Immediately after the Revolution, Lenin destroyed the
    Russian Church and destroyed physically people who
    were servants of the church, priests, and officials who
    were servants of other religions. Also many people who
    just believed in God and who didn't want to switch to
    Atheism were physically destroyed.

    I think it can be explained why Communist rulers in
    virtually all countries, in Russia, China, Cuba, have
    always been hostile to religion. A Communist regime is

    1 you

    slavery, and the prime goal, the prime concern of
    Communist rulers is to convince their subjects that there is
    nothing in this world beyond materialist values, that there
    is no life after this life. And in order to have a good life,
    they should serve Communism well. And in this case they
    should, otherwise, they will be punished, and there are no
    other values for which you should receive rewards and take

    Religious people believe in God, in a life hereafter, in
    certain religious and moral values. And a religious
    person when pressed too far by Communist authorities, is
    likely to say, 'I won't do it, I draw the line. I won't cross
    this line, no matter what you are going to do to me, or to
    my family. I won't do it because it is immoral. You can
    do to me whatever you want. I would rather die, but I
    won't commit this act of betrayal of morality ' And
    therefore, for Communist rulers, religion is a dangerous
    phenomenon. And they are doing everything they can to
    discredit, and destroy religion. . . .

    119

    Babylon's War Against God

    There is no religious freedom in Soviet Russia today
    ak a toe - 4

    punishment.
    ne: